==> codecs-antix_16.23.tar.xz: codecs-antix/translations/codecs_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>Özel kilit alınamadı</translation>
    </message>
    <message>
        <location filename="main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Başka bir paket yönetim uygulaması (Synaptic veya apt-get gibi) zaten çalışıyor. Lütfen önce bu uygulamayı kapatın</translation>
    </message>
    <message>
        <location filename="main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Bu programı root olarak çalıştırmalısınız.</translation>
    </message>
</context>
<context>
    <name>codecs</name>
    <message>
        <location filename="codecs.ui" line="14"/>
        <source>Codecs Installer</source>
        <translation>Çözücü Kurucusu</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Bu uygulama, gelişmiş video ve ses işlevlerine izin veren sınırlı çözücü bileşenlerini yüklemenizi sağlar.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Bazı yerel mahkemeler dağıtımları sınırlandırabilir.Bu nedenle kullanıcı yerel düzenlemelere uymalıdır. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Çözücü bileşenlerinin indirmenin yasal sorumluluğunu üstleniyor musun?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Çözücü dosyaları indiriliyor</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Değişiklikleri iptal et ve çık</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="97"/>
        <location filename="codecs.cpp" line="269"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>Değişiklikleri uygula ve çık</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="121"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="177"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="180"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="217"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="220"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="110"/>
        <location filename="codecs.cpp" line="117"/>
        <location filename="codecs.cpp" line="125"/>
        <location filename="codecs.cpp" line="132"/>
        <location filename="codecs.cpp" line="140"/>
        <location filename="codecs.cpp" line="147"/>
        <location filename="codecs.cpp" line="156"/>
        <location filename="codecs.cpp" line="163"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Komut Çalıştırılıyor...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="113"/>
        <location filename="codecs.cpp" line="128"/>
        <location filename="codecs.cpp" line="134"/>
        <location filename="codecs.cpp" line="143"/>
        <location filename="codecs.cpp" line="149"/>
        <location filename="codecs.cpp" line="159"/>
        <location filename="codecs.cpp" line="165"/>
        <location filename="codecs.cpp" line="194"/>
        <location filename="codecs.cpp" line="246"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="114"/>
        <location filename="codecs.cpp" line="129"/>
        <location filename="codecs.cpp" line="144"/>
        <location filename="codecs.cpp" line="160"/>
        <source>Cannot connect to the download site</source>
        <translation>İndirilecek siteye bağlanılamıyor</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="120"/>
        <location filename="codecs.cpp" line="135"/>
        <location filename="codecs.cpp" line="150"/>
        <location filename="codecs.cpp" line="166"/>
        <source>Error downloading %1</source>
        <translation>%1 indirilirken hata</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="171"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;İndirme Tamamlandı.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="190"/>
        <source>Installing downloaded files</source>
        <translation>İndirilen dosyalar kuruluyor</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="195"/>
        <source>No downloaded *.debs files found.</source>
        <translation>İndirilmiş *.debs dosyası bulunamadı.</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="211"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Kuruluyor...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="215"/>
        <source>Error installing %1</source>
        <translation>%1 kurulurken hata</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="239"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Kurulum işlemi tamamlandı&lt;b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="242"/>
        <source>Finished</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="243"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Çözücü dosyaları başarılı bir şekilde indirildi ve kuruldu.</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="247"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Süreç tamamlandı.Kurulum sırasıda bir hata oluştu.</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="262"/>
        <source>About Codecs</source>
        <translation>Çözücüleri Hakkında</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="263"/>
        <source>Codecs</source>
        <translation>Çözücüleri</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="263"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="265"/>
        <source>Simple codecs downloader for antiX Linux</source>
        <translation>antiX Linux için basit çözücü indiricisi</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="266"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="267"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="268"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="284"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
</TS>

==> codecs-antix_21.0.1.tar.xz: codecs-antix/translations/codecs_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Codecs Installer</source>
        <translation>Çözücü Kurucusu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Bu uygulama, gelişmiş video ve ses işlevlerine izin veren sınırlı çözücü bileşenlerini yüklemenizi sağlar.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Bazı yerel mahkemeler dağıtımları sınırlandırabilir.Bu nedenle kullanıcı yerel düzenlemelere uymalıdır. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Çözücü bileşenlerinin indirmenin yasal sorumluluğunu üstleniyor musun?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Çözücü dosyaları indiriliyor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Değişiklikleri iptal et ve çık</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="97"/>
        <location filename="mainwindow.cpp" line="268"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="104"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="117"/>
        <source>Apply any changes then quit</source>
        <translation>Değişiklikleri uygula ve çık</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="214"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="217"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="105"/>
        <location filename="mainwindow.cpp" line="112"/>
        <location filename="mainwindow.cpp" line="120"/>
        <location filename="mainwindow.cpp" line="128"/>
        <location filename="mainwindow.cpp" line="137"/>
        <location filename="mainwindow.cpp" line="144"/>
        <location filename="mainwindow.cpp" line="153"/>
        <location filename="mainwindow.cpp" line="161"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Komut Çalıştırılıyor...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="108"/>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="131"/>
        <location filename="mainwindow.cpp" line="140"/>
        <location filename="mainwindow.cpp" line="146"/>
        <location filename="mainwindow.cpp" line="157"/>
        <location filename="mainwindow.cpp" line="164"/>
        <location filename="mainwindow.cpp" line="193"/>
        <location filename="mainwindow.cpp" line="246"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="109"/>
        <location filename="mainwindow.cpp" line="125"/>
        <location filename="mainwindow.cpp" line="141"/>
        <location filename="mainwindow.cpp" line="158"/>
        <source>Cannot connect to the download site</source>
        <translation>İndirilecek siteye bağlanılamıyor</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="115"/>
        <location filename="mainwindow.cpp" line="132"/>
        <location filename="mainwindow.cpp" line="147"/>
        <location filename="mainwindow.cpp" line="165"/>
        <source>Error downloading %1</source>
        <translation>%1 indirilirken hata</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="170"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;İndirme Tamamlandı.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="189"/>
        <source>Installing downloaded files</source>
        <translation>İndirilen dosyalar kuruluyor</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="194"/>
        <source>No downloaded *.debs files found.</source>
        <translation>İndirilmiş *.debs dosyası bulunamadı.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="207"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Kuruluyor...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="220"/>
        <source>Error installing %1</source>
        <translation>%1 kurulurken hata</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="224"/>
        <source>Fix missing dependencies...</source>
        <translation>Eksik bağımlılıkları onar...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="226"/>
        <source>Error running %1 command</source>
        <translation>% 1 komutu çalıştırılırken hata oluştu</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="238"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Kurulum işlemi tamamlandı&lt;b&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="242"/>
        <source>Finished</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="243"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Çözücü dosyaları başarılı bir şekilde indirildi ve kuruldu.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="247"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Süreç tamamlandı.Kurulum sırasıda bir hata oluştu.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="261"/>
        <source>About Codecs</source>
        <translation>Çözücüleri Hakkında</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="262"/>
        <source>Codecs</source>
        <translation>Çözücüler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="262"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="264"/>
        <source>Simple codecs downloader for antiX Linux</source>
        <translation>antiX Linux için basit çözücü indiricisi</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="266"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <location filename="mainwindow.cpp" line="277"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>Özel kilit alınamadı</translation>
    </message>
    <message>
        <location filename="main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Başka bir paket yönetim uygulaması (Synaptic veya apt-get gibi) zaten çalışıyor. Lütfen önce bu uygulamayı kapatın</translation>
    </message>
    <message>
        <location filename="main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Bu programı root olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
